@@ -209,8 +209,12 @@ class OpenEuler():
         branch=f"openEuler-{os_version}"
         rpm_list = []
         with tempfile.TemporaryDirectory() as temp_dir:
-            git.Repo.clone_from(repo_url, temp_dir, branch=branch, depth=1)
-            log.info(f"clone {repo_name} success")
+            try:
+                git.Repo.clone_from(repo_url, temp_dir, branch=branch, depth=1)
+                log.info(f"clone {repo_name} success")
+            except Exception as e:
+                log.error(f"clone {repo_name} failed, error is {e}")
+                return rpm_list
             spec_files = list(Path(temp_dir).rglob("*.spec"))
 
             for spec_file in spec_files:
@@ -265,6 +269,15 @@ class OpenEuler():
                 log.info(f"仓库 {repo_name}（{repo_url}）已找到目标版本分支 {branch}")
                 yield repo_name, repo_url
 
+    def get_rpm_name_from_full_name(self, rpm):
+        pattern = r"^(.+?)-\d"
+        match = re.match(pattern, rpm)
+        if match:
+            return match.group(1)
+        else:
+            log.warning(f"{rpm} does not match the pattern")
+            return None
+
     def get_openEuler_everything_pkgs(
             self, os_version: str, os_arch: str
     ) -> Generator[str, None, None]:
@@ -323,15 +336,22 @@ class OpenEuler():
         for link in pkg_links:
             full_pkg_name = link.get("href", "").strip()
             if full_pkg_name:  # 过滤空字符串
-                yield full_pkg_name
+                pkg_name=self.get_rpm_name_from_full_name(full_pkg_name)
+                yield pkg_name,full_pkg_name
 
 
 
 if __name__ == "__main__":
     # 初始化获取器
     oe = OpenEuler()
-    for rpm in oe.get_openEuler_rpm_names_from_repo("24.03-LTS-SP2", "python-minio","https://gitee.com/src-openeuler/python-minio.git"):
-        print(f"src_name:python-minio,rpm:{rpm}")
+    count=0
+    effective_count=0
+    for rpm_name,rpm_full_name in oe.get_openEuler_everything_pkgs("24.03-LTS-SP1", "x86_64"):
+        count+=1
+        print(f"{rpm_name}：{rpm_full_name}")
+    print(f"共获取到 {count} 个包")
+    # for rpm in oe.get_openEuler_rpm_names_from_repo("24.03-LTS-SP2", "python-minio","https://gitee.com/src-openeuler/python-minio.git"):
+    #     print(f"src_name:python-minio,rpm:{rpm}")
     # log.info("正在初始化 Gitee 模块...")
     # repos_generator = oe.get_openEuler_repo_names_and_urls(
     #     os_version="24.03-LTS-SP2"
